@@ -115,7 +115,7 @@ class DockerApplication(object):
         self.wikiUser=None
        
     @staticmethod 
-    def check(debug:bool=False)->str:
+    def checkDockerEnvironment(debug:bool=False)->str:
         """
         check the docker environment
         
@@ -138,6 +138,43 @@ class DockerApplication(object):
                         print(f"""modified PATH from {os_path} to \n{os.environ["PATH"]}""")
         return errMsg
     
+    def check(self)->int:
+        """
+        check me
+        
+        Returns:
+            int: exitCode: 0 if ok, 1 if not ok
+        """
+        DockerApplication.checkDockerEnvironment(self.config.debug) 
+        exitCode=0
+        mw,db=self.getContainers()
+        if not mw:
+            print("mediawiki container missing")
+            exitCode=1
+        if  not db:
+            print("database container missing")
+            exitCode=1
+        if mw and db and mw.check() and db.check():
+            pb_dict=mw.container.host_config.port_bindings
+            p80="80/tcp"
+            if p80 in pb_dict:
+                pb=pb_dict[p80][0]
+                host_port=pb.host_port
+                Logger.check_and_log_equal(f"port binding",host_port,"expected  port",str(self.config.port))
+                url=self.config.url
+                # fix url to local port
+                url=url.replace(str(self.config.port),host_port)
+                version_url=f"{url}/index.php/Special:Version"
+                
+                ok=self.checkWiki(version_url)
+                if not ok:
+                    exitCode=1
+            else:
+                self.log(f"port binding {p80} missing",False)
+                exitCode=1
+            pass
+        return exitCode
+    
     def checkWiki(self,version_url:str)->bool:
         """
         check this wiki against the content of the given version_url
@@ -468,11 +505,16 @@ class DockerApplication(object):
         and https://gabrieldemarmiesse.github.io/python-on-whales/sub-commands/compose/#down
         
         """
+        DockerApplication.checkDockerEnvironment(self.config.debug) 
         # change directory so that docker CLI will find the relevant dockerfile and docker-compose.yml
         if self.config.verbose:
             print(f"running docker compose down for {self.config.container_base_name} {self.config.version} docker application ...")
+        # remember current directory 
+        cwd = os.getcwd()    
         os.chdir(self.dockerPath)
         docker.compose.down(volumes=forceRebuild) 
+        # switch back to previous current directory
+        os.chdir(cwd)
         
     def up(self,forceRebuild:bool=False):
         """
@@ -480,18 +522,38 @@ class DockerApplication(object):
         
         Args: 
             forceRebuild(bool): if true stop and remove the existing containers
-        """            
+        """     
+        DockerApplication.checkDockerEnvironment(self.config.debug)       
         if self.config.verbose:
             print(f"starting {self.config.container_base_name} {self.config.version} docker application ...")
         if forceRebuild:
             for docker_container in [self.dbContainer,self.mwContainer]:
                 if docker_container is not None:
                     container=docker_container.container
-                    if self.config.verbose:
-                        print(f"stopping and removing container {container.name}")
-                    container.stop()
-                    container.remove()
+                    try:
+                        container_name=container.name
+                        if self.config.verbose:
+                            print(f"stopping and removing container {container_name}")
+                    except Exception as container_ex:
+                        container=None
+                    if container:
+                        try:
+                            container.stop()
+                        except Exception as stop_ex:
+                            if self.config.verbose:
+                                print(f"stop failed with {str(stop_ex)}")
+                            pass
+                        try:
+                            container.remove()
+                        except Exception as remove_ex:
+                            if self.config.verbose:
+                                print(f"removed failed with {str(remove_ex)}")
+                            pass
+                    pass
 
+        # remember current directory 
+        cwd = os.getcwd()    
+     
         # change directory so that docker CLI will find the relevant dockerfile and docker-compose.yml
         os.chdir(self.dockerPath)
         #project_config = docker.compose.config()
@@ -501,6 +563,9 @@ class DockerApplication(object):
         # this might take a while e.g. downloading
         # run docker compose up
         docker.compose.up(detach=True,force_recreate=forceRebuild)      
+        # switch back to previous current directory
+        os.chdir(cwd)
+    
         return self.getContainers()
         
     def start(self,forceRebuild:bool=False,withInitDB=True):
